Stan Math Library: Namespace Members

| Stan Math Library 2.10.0 reverse mode automatic differentiation

- Main Page
- Modules
- Namespaces
- Classes
- Files

- Namespace List
- Namespace Members

- All
- Functions
- Variables
- Typedefs

- a
- b
- c
- d
- e
- f
- g
- h
- i
- j
- l
- m
- n
- o
- p
- q
- r
- s
- t
- u
- v
- w

Here is a list of all namespace members with links to the namespace documentation for each member:

### - v -

- validate_non_negative_index() : stan::math
- value_of() : stan::math
- value_of< double >() : stan::math
- value_of_rec() : stan::math
- value_of_rec< double >() : stan::math
- variance() : stan::math
- vector_d : stan::math
- vector_fd : stan::math
- vector_ffd : stan::math
- vector_ffv : stan::math
- vector_fv : stan::math
- vector_v : stan::math
- von_mises_log() : stan::math
- von_mises_rng() : stan::math

[ Stan Home Page ] © 2011–2016, Stan Development Team.